@@ -2,6 +2,12 @@ from .init import Module
 
 
 class Distro(Module):
+    '''Send Public Key to Target
+    kw:
+        usr : User name
+        pub : Piblic key
+    '''
+
     def deploy(self, target, **kw):
 
         usr = kw['usr']
