@@ -2,6 +2,13 @@ from .init import Module, error
 
 
 class Distro(Module):
+    '''Download File
+
+    kw:
+        url : File's URL
+        dst : File's Dest (defaults to "downloaded"
+    '''
+
     def deploy(self, target, **kw):
         url, dst = kw['url'], kw.get('dst')
         dst = dst or 'downloaded'
