@@ -5,6 +5,12 @@ from .init import Module
 
 
 class Distro(Module):
+    '''Add User to sudoers
+
+    arg:
+        user : user name
+    '''
+
     def deploy(self, target, *, user):
 
         line = f'{user} ALL=(ALL) NOPASSWD: ALL\n'
